@@ -22,7 +22,31 @@ Readonly::Scalar my $LINE_SIZE => 79;
 Readonly::Scalar my $SPACE => q{ };
 
 # Version.
-our $VERSION = 0.04;
+our $VERSION = 0.05;
+
+# Finalize Tags output.
+sub finalize {
+	my $self = shift;
+
+	# XML mode.
+	if ($self->{'xml'}) {
+
+		# Add ending of all opened tags.
+		while (@{$self->{'printed_tags'}}) {
+			$self->put(['e', $self->{'printed_tags'}->[0]]);
+		}
+
+	# SGML mode.
+	} else {
+
+		# Flush tmp code.
+		if (scalar @{$self->{'tmp_code'}}) {
+			$self->_print_tag('>');
+		}
+		$self->{'printed_tags'} = [];
+	}
+	return;
+}
 
 # Resets internal variables.
 sub reset {
@@ -768,11 +792,11 @@ Michal Špaček L<skim@cpan.org>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2011-2015 Michal Špaček
+ © 2011-2016 Michal Špaček
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
